@@ -2,6 +2,9 @@
 import datetime
 import time
 import uuid
+
+from django.contrib.postgres.fields import JSONField
+from django.contrib.postgres.indexes import BrinIndex
 from django.db import models
 from django.template.defaultfilters import slugify
 from django.conf import settings
@@ -21,7 +24,7 @@ class RestFileManagerStorage(S3Boto3Storage):
 
 def get_file_system_storage():
     if getattr(settings, 'S3_STORAGE'):
-        return RestFileManagerStorage(location=getattr(settings, 'AWS_LOCATION', 'files'))
+        return RestFileManagerStorage()
     else:
         return default_storage
 
@@ -42,11 +45,12 @@ class File(models.Model):
         storage=get_file_system_storage(),
         upload_to=set_storage_file_dir,
         blank=False,
+        max_length=255,
         null=True
     )
     name = models.CharField(
         verbose_name='Name',
-        max_length=100
+        max_length=255
     )
     username = models.CharField(
         'Username',
@@ -72,7 +76,8 @@ class File(models.Model):
         blank=True,
         null=True,
         max_length=10,
-        default='file'
+        default='file',
+        db_index=True,
     )
     permission = models.CharField(
         verbose_name='Permission',
@@ -89,11 +94,14 @@ class File(models.Model):
         'Status',
         max_length=3
     )
-    data = models.TextField(default=dict, blank=True, null=True)
+    data = JSONField(default=dict, blank=True, null=True)
 
     class Meta:
         verbose_name = 'File'
         verbose_name_plural = 'Files'
+        indexes = (
+            BrinIndex(fields=('creation_date', )),
+        )
 
     def __str__(self):
         return '{}-{}'.format(self.name, self.type)
